"""
Tools module for the Omelet Routing Engine MCP server.
Import all tool modules here to register them with the server.
"""

# Import all tool modules to register them
from . import doc_tools

__all__ = ["doc_tools"]
